@@ -198,9 +198,6 @@ sub search_get($$;)
 1;
 
 
-__END__
-
-
 =pod
 
 =head1 NAME
@@ -350,9 +347,3 @@ This package is free software and is provided "as is" without express
 or implied warranty. It may be used, redistributed and/or modified
 under the same terms as perl itself.
 
-=end
-
-
-
-
-
