@@ -32,7 +32,6 @@ sub new ()
 
 1;
 
-__END__
 
 =pod
 
@@ -84,5 +83,3 @@ This package is free software and is provided "as is" without express
 or implied warranty. It may be used, redistributed and/or modified
 under the same terms as perl itself.
 
-=end
-
