@@ -67,7 +67,6 @@ sub layout ()
 
 1;
 
-__END__
 
 =pod
 
@@ -140,8 +139,3 @@ This package is free software and is provided "as is" without express
 or implied warranty. It may be used, redistributed and/or modified
 under the same terms as perl itself.
 
-=end
-
-
-
-
